@@ -1,11 +1,10 @@
-import { CommonModule } from "@angular/common"
-import { NgModule } from "@angular/core"
-import { Routes } from "@angular/router"
-import { FormsModule } from "@angular/forms"
-import { NzIconModule } from "ng-zorro-antd/icon"
-import { RouterModule } from "@angular/router"
-import { HttpClientModule } from "@angular/common/http"
-import { SearchCfgComponent } from "./search-cfg.component"
+import { CommonModule } from "@angular/common";
+import { NgModule } from "@angular/core";
+import { RouterModule, Routes } from "@angular/router";
+import { FormsModule } from "@angular/forms";
+import { NzIconModule } from "ng-zorro-antd/icon";
+import { HttpClientModule } from "@angular/common/http";
+import { SearchCfgComponent } from "./search-cfg.component";
 
 // Define the child routes for this plugin.
 export const pluginRoutes: Routes = [
@@ -18,7 +17,7 @@ export const pluginRoutes: Routes = [
         pathMatch: "full",
         component: SearchCfgComponent,
     },
-]
+];
 
 // Define the root module for this plugin.
 // This module is loaded by the lazy loader, what ever this defines is what is started.
@@ -35,5 +34,4 @@ export const pluginRoutes: Routes = [
     providers: [],
     declarations: [SearchCfgComponent],
 })
-export class SearchCfgModule {
-}
+export class SearchCfgModule {}
