@@ -9,6 +9,7 @@ import {
     TupleOfflineStorageNameService,
     TupleOfflineStorageService,
     TupleSelector,
+    TupleStorageBatchSaveArguments,
     TupleStorageFactoryService,
     VortexService,
     VortexStatusService,
@@ -27,7 +28,7 @@ import { SearchTupleService } from "../SearchTupleService";
 import { PrivateSearchObjectLoaderStatusTuple } from "./PrivateSearchObjectLoaderStatusTuple";
 import { SearchObjectTypeTuple } from "../../SearchObjectTypeTuple";
 import {
-    DeviceOfflineCacheControllerService,
+    DeviceOfflineCacheService,
     OfflineCacheStatusTuple,
 } from "@peek/peek_core_device";
 
@@ -103,7 +104,12 @@ function objectIdChunk(objectId: number): string {
 @Injectable()
 export class PrivateSearchObjectLoaderService extends NgLifeCycleEvents {
     private UPDATE_CHUNK_FETCH_SIZE = 5;
-    private OFFLINE_CHECK_PERIOD_MS = 15 * 60 * 1000; // 15 minutes
+
+    // Every 100 chunks from the server
+    private SAVE_POINT_ITERATIONS = 100;
+
+    // Saving the cache after each chunk is so expensive, we only do it every 20 or so
+    private chunksSavedSinceLastIndexSave = 0;
 
     private index = new SearchObjectUpdateDateTuple();
     private askServerChunks: SearchObjectUpdateDateTuple[] = [];
@@ -122,7 +128,7 @@ export class PrivateSearchObjectLoaderService extends NgLifeCycleEvents {
         private vortexStatusService: VortexStatusService,
         storageFactory: TupleStorageFactoryService,
         private tupleService: SearchTupleService,
-        private deviceCacheControllerService: DeviceOfflineCacheControllerService
+        private deviceCacheControllerService: DeviceOfflineCacheService
     ) {
         super();
 
@@ -240,7 +246,7 @@ export class PrivateSearchObjectLoaderService extends NgLifeCycleEvents {
             )
             .pipe(takeUntil(this.onDestroyEvent))
             .subscribe((payloadEnvelope: PayloadEnvelope) => {
-                this.processSearchObjectsFromServer(payloadEnvelope);
+                this.processChunksFromServer(payloadEnvelope);
             });
 
         // If the vortex service comes back online, update the watch grids.
@@ -252,7 +258,7 @@ export class PrivateSearchObjectLoaderService extends NgLifeCycleEvents {
 
     private areWeTalkingToTheServer(): boolean {
         return (
-            this.deviceCacheControllerService.cachingEnabled &&
+            this.deviceCacheControllerService.offlineModeEnabled &&
             this.vortexStatusService.snapshot.isOnline
         );
     }
@@ -336,95 +342,103 @@ export class PrivateSearchObjectLoaderService extends NgLifeCycleEvents {
 
         if (this.askServerChunks.length == 0) return;
 
-        let indexChunk: SearchObjectUpdateDateTuple =
-            this.askServerChunks.pop();
-        let filt = extend({}, clientSearchObjectWatchUpdateFromDeviceFilt);
-        filt[cacheAll] = true;
-        let pl = new Payload(filt, [indexChunk]);
-        this.vortexService.sendPayload(pl);
+        this.deviceCacheControllerService //
+            .waitForGarbageCollector()
+            .then(() => {
+                let indexChunk: SearchObjectUpdateDateTuple =
+                    this.askServerChunks.pop();
+                let filt = extend(
+                    {},
+                    clientSearchObjectWatchUpdateFromDeviceFilt
+                );
+                filt[cacheAll] = true;
+                let pl = new Payload(filt, [indexChunk]);
+                this.vortexService.sendPayload(pl);
 
-        this._status.lastCheck = new Date();
-        this._notifyStatus();
+                this._status.lastCheck = new Date();
+                this._notifyStatus();
+            });
     }
 
     /** Process SearchObjects From Server
      *
      * Process the grids the server has sent us.
      */
-    private processSearchObjectsFromServer(payloadEnvelope: PayloadEnvelope) {
+    private async processChunksFromServer(
+        payloadEnvelope: PayloadEnvelope
+    ): Promise<void> {
         if (payloadEnvelope.result != null && payloadEnvelope.result != true) {
             console.log(`ERROR: ${payloadEnvelope.result}`);
             return;
         }
 
-        payloadEnvelope
-            .decodePayload()
-            .then((payload: Payload) => this.storeSearchObjectPayload(payload))
-            .then(() => {
-                if (this.askServerChunks.length == 0) {
-                    this.index.initialLoadComplete = true;
-                    this._hasLoaded = true;
-                    this._hasLoadedSubject.next();
-                } else if (payloadEnvelope.filt[cacheAll] == true) {
-                    this.askServerForNextUpdateChunk();
-                }
-            })
-            .then(() => this._notifyStatus())
-            .catch(
-                (e) =>
-                    `SearchObjectCache.processSearchObjectsFromServer failed: ${e}`
-            );
-    }
-
-    private storeSearchObjectPayload(payload: Payload) {
-        let tuplesToSave: EncodedSearchObjectChunkTuple[] = <
+        const tuplesToSave: EncodedSearchObjectChunkTuple[] = <
             EncodedSearchObjectChunkTuple[]
-        >payload.tuples;
-        if (tuplesToSave.length == 0) return;
+        >payloadEnvelope.data;
 
-        // 2) Store the index
-        this.storeSearchObjectChunkTuples(tuplesToSave)
-            .then(() => {
-                // 3) Store the update date
+        try {
+            await this.storeChunkTuples(tuplesToSave);
+        } catch (e) {
+            console.log(`SearchObjectCache.storeSearchObjectPayload: ${e}`);
+        }
 
-                for (let searchIndex of tuplesToSave) {
-                    this.index.updateDateByChunkKey[searchIndex.chunkKey] =
-                        searchIndex.lastUpdate;
-                }
+        if (this.askServerChunks.length == 0) {
+            this.index.initialLoadComplete = true;
+            await this.saveChunkCacheIndex(true);
+            this._hasLoaded = true;
+            this._hasLoadedSubject.next();
+        } else if (payloadEnvelope.filt[cacheAll] == true) {
+            this.askServerForNextUpdateChunk();
+        }
 
-                return this.storage.saveTuples(new UpdateDateTupleSelector(), [
-                    this.index,
-                ]);
-            })
-            .catch((e) =>
-                console.log(`SearchObjectCache.storeSearchObjectPayload: ${e}`)
-            );
+        this._notifyStatus();
     }
 
     /** Store Index Bucket
      * Stores the index bucket in the local db.
      */
-    private storeSearchObjectChunkTuples(
-        encodedSearchObjectChunkTuples: EncodedSearchObjectChunkTuple[]
+    private async storeChunkTuples(
+        tuplesToSave: EncodedSearchObjectChunkTuple[]
     ): Promise<void> {
-        let retPromise: any;
-        retPromise = this.storage.transaction(true).then((tx) => {
-            let promises = [];
+        // noinspection BadExpressionStatementJS
+        const Selector = SearchObjectChunkTupleSelector;
 
-            for (let encodedSearchObjectChunkTuple of encodedSearchObjectChunkTuples) {
-                promises.push(
-                    tx.saveTuplesEncoded(
-                        new SearchObjectChunkTupleSelector(
-                            encodedSearchObjectChunkTuple.chunkKey
-                        ),
-                        encodedSearchObjectChunkTuple.encodedData
-                    )
-                );
-            }
+        if (tuplesToSave.length == 0) return;
 
-            return Promise.all(promises).then(() => tx.close());
-        });
-        return retPromise;
+        const batchStore: TupleStorageBatchSaveArguments[] = [];
+        for (const tuple of tuplesToSave) {
+            batchStore.push({
+                tupleSelector: new Selector(tuple.chunkKey),
+                vortexMsg: tuple.encodedData,
+            });
+        }
+
+        await this.storage.batchSaveTuplesEncoded(batchStore);
+
+        for (const tuple of tuplesToSave) {
+            this.index.updateDateByChunkKey[tuple.chunkKey] = tuple.lastUpdate;
+        }
+        await this.saveChunkCacheIndex(true);
+    }
+
+    /** Store Chunk Cache Index
+     *
+     * Updates our running tab of the update dates of the cached chunks
+     *
+     */
+    private async saveChunkCacheIndex(force = false): Promise<void> {
+        if (
+            this.chunksSavedSinceLastIndexSave <= this.SAVE_POINT_ITERATIONS &&
+            !force
+        ) {
+            return;
+        }
+
+        this.chunksSavedSinceLastIndexSave = 0;
+
+        await this.storage.saveTuples(new UpdateDateTupleSelector(), [
+            this.index,
+        ]);
     }
 
     /** Get Objects When Ready
